==> haskell-arrows-0.4.4.2-126-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-61TEwK6PA9hFsDT1xpoBAG
key:                  arrows-0.4.4.2-61TEwK6PA9hFsDT1xpoBAG
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  20265bde25f5b1bad05679cd8b77eca0
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.2.8/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-61TEwK6PA9hFsDT1xpoBAG
depends:              Stream-0.4.7.2-IscoXykheD4BbYkWvMPsAo base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arrows-0.4.4.2-128-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-BCor81cbXjLLdBo1KFEnGl
key:                  arrows-0.4.4.2-BCor81cbXjLLdBo1KFEnGl
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  a54bff4f4ba0b704b35d8d5df381d048
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.2.8/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-BCor81cbXjLLdBo1KFEnGl
depends:              Stream-0.4.7.2-5KYedP6GvCyVV6NAYEV34 base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
